# -*- coding: utf-8 -*-
#########################################################
##
##  @brief  MiarmyGUI集約
##  @file   GUIcollection.py
##  @author Satoshi Gonokami
##
##  Copyright(C) 2014 Digital Frontier Inc.
##
##    [免責事項]
##        本ツール、コードを使用したことによって
##        引き起こるいかなる損害も当方は一切責任を負いかねます。
##        自己責任でご使用ください。
##        
##        Terms of Use
##        The following script is provided for your conveniece and is used at your
##        own discretion and risk. Digital Frontier is not responsible for any
##        damage to your computer system or loss of data that results from the
##        access, download and use of the content on this site.
##
#########################################################
import os
import sys
import re

from PySide import QtCore
from PySide import QtGui
from PySide.QtUiTools import QUiLoader
try:
    import shiboken
except:
    from PySide import shiboken
import pymel.core as pm
import maya.OpenMayaUI as omUI


from McdMiarmyToolsGUI import *
from McdMiarmyGlobalGUI import *
from McdPhysicsGlobalGUI import *
from McdRenderSettingGUI import *

from McdAgentViewerGUI import *
from McdSimpleCmd import *

from McdAgentManagerGUI import *
from McdTerrainManagerGUI import *
from McdAgentParticleEmitterGUI import *
from McdGeoVisManagerGUI import *
from McdVarManagerGUI import *
from McdGroupVarEditorGUI import *
from McdVarPxyManagerGUI import *
from McdGroupVarEditorGUI import *

from McdActionEditorGUI import *
from McdActionProxyEditorGUI import *
from McdActionSyncEditorGUI import *
from McdStoryListEditorGUI import *
from McdPlacementEditorGUI import *
from McdDecisionEditorGUI import *
from McdAgentRBDEmitterGUI import *


import GS_Miarmy.define as DFMdef
reload(DFMdef)

CURRENT_DIR = DFMdef.currentDir

##---------------------------------------------------------
## get maya Window(thank to Ishida-san)
##---------------------------------------------------------
## @param None
## @return None
def getDCCWindow():
    try:
        ptr = omUI.MQtUtil.mainWindow()
        if ptr is not None:
            return shiboken.wrapInstance(long(ptr), QtGui.QMainWindow)
    except:
        return None

##---------------------------------------------------------
## FrameLayout class(thank to tazmim)
##---------------------------------------------------------
class FrameLayout(object):

    def __init__(self, titleBar, frame):
        self.titleBar = titleBar    ## 上のボタンウィジェット
        self.frame = frame          ## 開閉するウィジェット
        self.collapse = False       ## 開閉している状態フラグ
        self.setSignals()           ## シグナルをセット

    ##---------------------------------------------------------
    ## シグナルを設定する
    ##---------------------------------------------------------
    ## @param None
    ## @return None
    def setSignals(self):
        self.titleBar.clicked.connect(self.setCollapse)

    ##---------------------------------------------------------
    ## open
    ##---------------------------------------------------------
    ## @param None
    ## @return None
    def setOpen(self):
        self.frame.setHidden(False)
        self.titleBar.setArrowType(QtCore.Qt.DownArrow)


    ##---------------------------------------------------------
    ## close
    ##---------------------------------------------------------
    ## @param None
    ## @return None
    def setClose(self):
        self.frame.setHidden(True)
        self.titleBar.setArrowType(QtCore.Qt.RightArrow)


    ##---------------------------------------------------------
    ## enable
    ##---------------------------------------------------------
    ## @param None
    ## @return None
    def setEnabled(self):
        self.frame.setEnabled(True)
        self.titleBar.setEnabled(True)


    ##---------------------------------------------------------
    ## disable
    ##---------------------------------------------------------
    ## @param None
    ## @return None
    def setDisabled(self):
        self.frame.setEnabled(False)
        self.titleBar.setEnabled(False)


    ##---------------------------------------------------------
    ## フレームを開閉するアクション
    ##---------------------------------------------------------
    ## @param None
    ## @return None
    def setCollapse(self):
        ## 現在のステータスを反転する
        self.collapse = not self.collapse
        ## フレームのビジビリティを変更する
        self.frame.setHidden(self.collapse)

        ## 開閉状況に合わせてアロータイプを変更する
        if self.collapse:
            ## 閉じている時は右に向ける
            self.titleBar.setArrowType(QtCore.Qt.RightArrow)
        else:
            ## 開いている時は下へ向ける
            self.titleBar.setArrowType(QtCore.Qt.DownArrow)


##---------------------------------------------------------
## GUI class
##---------------------------------------------------------
class GUI(QtGui.QMainWindow):

    global CURRENT_DIR

    _CDIR = CURRENT_DIR

    windowName = 'MiarmyGUIcollection'
    windowTitle = u'Miarmy GUI Collection'
    UIpath = CURRENT_DIR + '/ui/GUIcollection.ui'
    iconPath = CURRENT_DIR + '/icon'

    defWidth = 430
    defHeight = 640


    ##---------------------------------------------------------
    ## init
    ##---------------------------------------------------------
    ## @param <object>parent : parent widget
    ## @return None
    def __init__(self, parent=getDCCWindow()):
        super(GUI, self).__init__(parent)

        loader = QUiLoader()
        self.UI = loader.load(self.UIpath)
        self.setWindowTitle(self.windowTitle)
        self.setObjectName(self.windowName)
        self.setCentralWidget(self.UI)

        ## set frameLayout
        self.windowFrameLayout  = FrameLayout(self.UI.windowFrameButton, self.UI.windowGroupBox)
        self.viewerFrameLayout  = FrameLayout(self.UI.viewerFrameButton, self.UI.viewerGroupBox)
        self.managerFrameLayout = FrameLayout(self.UI.managerFrameButton, self.UI.managerGroupBox)
        self.editorFrameLayout  = FrameLayout(self.UI.editorFrameButton, self.UI.editorGroupBox)
        self.customFrameLayout  = FrameLayout(self.UI.customFrameButton, self.UI.customGroupBox)

        self.setSignals()

        ## get default stylesheet
        self.defStyleSheet = self.UI.styleSheet()

        self.defMToolBss         = self.UI.MiarmyToolButton.styleSheet()
        self.defMGlobalBss       = self.UI.MiarmyGlobalButton.styleSheet()
        self.defPGlobalBss       = self.UI.PhysicsGlobalButton.styleSheet()
        self.defRGlobalBss       = self.UI.RenderGlobalButton.styleSheet()

        self.defAgentVBss        = self.UI.AgentViewerButton.styleSheet()
        self.defTMapBss          = self.UI.TransitionMapButton.styleSheet()
        self.defBrainLogicVBss   = self.UI.BrainLogicViewerButton.styleSheet()

        self.defAgentMBss        = self.UI.AgentManagerButton.styleSheet()
        self.defTerrainMBss      = self.UI.TerrainManagerButton.styleSheet()
        self.defParticleEBss     = self.UI.ParticleEmitButton.styleSheet()
        self.defGeoHideBss       = self.UI.GeometryHideButton.styleSheet()
        self.defAgentVarMBss     = self.UI.AgentVariableManagerButton.styleSheet()
        self.defAgentVarHLBss    = self.UI.AgentVariableHostLinkerButton.styleSheet()
        self.defVarProxMBss      = self.UI.VariableProxyManagerButton.styleSheet()
        self.defVarProxLBss      = self.UI.VariableProxyLinkerButton.styleSheet()

        self.defActEBss          = self.UI.ActionEditorButton.styleSheet()
        self.defActProxyEBss     = self.UI.ActionProxyEditorButton.styleSheet()
        self.defActSyncBss       = self.UI.ActionSynchronizationButton.styleSheet()
        self.defStoryListEBss    = self.UI.StoryListEditorButton.styleSheet()
        self.defPlacementEBss    = self.UI.PlacementEditorButton.styleSheet()
        self.defDecNodeBss       = self.UI.DecisionNodeButton.styleSheet()
        self.defAgentRBDEBss     = self.UI.AgentRBDEmitButton.styleSheet()


        self.resize(self.defWidth, self.defHeight)
        self.initUI()


    ##---------------------------------------------------------
    ## initialize UI param
    ##---------------------------------------------------------
    ## @param None
    ## @return None
    def initUI(self):
        self.reloadUI()


    ##---------------------------------------------------------
    ## Set signals of widget
    ##---------------------------------------------------------
    ## @param None
    ## @return None
    def setSignals(self):
        ## button signals
        self.UI.MiarmyToolButton.clicked.connect(McdMiarmyToolsGUI)
        self.UI.MiarmyGlobalButton.clicked.connect(McdMiarmyGlobalGUI)
        self.UI.PhysicsGlobalButton.clicked.connect(McdPhysicsGlobalGUI)
        self.UI.RenderGlobalButton.clicked.connect(McdRenderSettingGUI)

        self.UI.AgentViewerButton.clicked.connect(McdAgentViewerGUI)
        self.UI.TransitionMapButton.clicked.connect(McdTransitionMapViewerGUI)
        self.UI.BrainLogicViewerButton.clicked.connect(McdBrainViewerGUI)

        self.UI.AgentManagerButton.clicked.connect(McdAgentManagerGUI)
        self.UI.TerrainManagerButton.clicked.connect(McdTerrainManagerGUI)
        self.UI.ParticleEmitButton.clicked.connect(McdAgentParticleEmitterGUI)
        self.UI.GeometryHideButton.clicked.connect(McdGeoVisManagerGUI)
        self.UI.AgentVariableManagerButton.clicked.connect(McdVarManagerGUI)
        self.UI.AgentVariableHostLinkerButton.clicked.connect(McdGroupVarEditorGUI)
        self.UI.VariableProxyManagerButton.clicked.connect(McdVarPxyManagerGUI)
        self.UI.VariableProxyLinkerButton.clicked.connect(McdGroupVarEditorGUI)

        self.UI.ActionEditorButton.clicked.connect(McdActionEditorGUI)
        self.UI.ActionProxyEditorButton.clicked.connect(McdActionProxyEditorGUI)
        self.UI.ActionSynchronizationButton.clicked.connect(McdActionSyncEditorGUI)
        self.UI.StoryListEditorButton.clicked.connect(McdStoryListEditorGUI)
        self.UI.PlacementEditorButton.clicked.connect(McdPlacementEditorGUI)
        self.UI.DecisionNodeButton.clicked.connect(McdDecisionEditorGUI)
        self.UI.AgentRBDEmitButton.clicked.connect(McdAgentRBDEmitterGUI)


    ##---------------------------------------------------------
    ## reloadUI
    ##---------------------------------------------------------
    ## @param None
    ## @return None
    def reloadUI(self):

        self.updateStyleSheet(self.UI.MiarmyToolButton, self.defMToolBss)
        self.updateStyleSheet(self.UI.MiarmyGlobalButton, self.defMGlobalBss)
        self.updateStyleSheet(self.UI.PhysicsGlobalButton, self.defPGlobalBss)
        self.updateStyleSheet(self.UI.RenderGlobalButton, self.defRGlobalBss)

        self.updateStyleSheet(self.UI.AgentViewerButton, self.defAgentVBss)
        self.updateStyleSheet(self.UI.TransitionMapButton, self.defTMapBss)
        self.updateStyleSheet(self.UI.BrainLogicViewerButton, self.defBrainLogicVBss)

        self.updateStyleSheet(self.UI.AgentManagerButton, self.defAgentMBss)
        self.updateStyleSheet(self.UI.TerrainManagerButton, self.defTerrainMBss)
        self.updateStyleSheet(self.UI.ParticleEmitButton, self.defParticleEBss)
        self.updateStyleSheet(self.UI.GeometryHideButton, self.defGeoHideBss)
        self.updateStyleSheet(self.UI.AgentVariableManagerButton, self.defAgentVarMBss)
        self.updateStyleSheet(self.UI.AgentVariableHostLinkerButton, self.defAgentVarHLBss)
        self.updateStyleSheet(self.UI.VariableProxyManagerButton, self.defVarProxMBss)
        self.updateStyleSheet(self.UI.VariableProxyLinkerButton, self.defVarProxLBss)

        self.updateStyleSheet(self.UI.ActionEditorButton, self.defActEBss)
        self.updateStyleSheet(self.UI.ActionProxyEditorButton, self.defActProxyEBss)
        self.updateStyleSheet(self.UI.ActionSynchronizationButton, self.defActSyncBss)
        self.updateStyleSheet(self.UI.StoryListEditorButton, self.defStoryListEBss)
        self.updateStyleSheet(self.UI.PlacementEditorButton, self.defPlacementEBss)
        self.updateStyleSheet(self.UI.DecisionNodeButton, self.defDecNodeBss)
        self.updateStyleSheet(self.UI.AgentRBDEmitButton, self.defAgentRBDEBss)


    ##---------------------------------------------------------
    ## update styleSheet
    ##---------------------------------------------------------
    ## @param <object>buttonUI : button UI object
    ## @param <str>stylSheet : styleSheet
    ## @return None
    def updateStyleSheet(self, buttonUI, stylSht):
        styleSheet = stylSht.replace('[IconImage]', self.iconPath)
        buttonUI.setStyleSheet(styleSheet)


##---------------------------------------------------------
## Call from console
##---------------------------------------------------------
## @param <strArray>argv : sys argv
## @param <int>mode : 0=window mode, 1=dockControl mode
## @return None
def main(*argv):

    mode = argv[0]

    global windowUI
    try:
        windowUI.close()
        windowUI.deleteLater()
    except: pass

    app = QtGui.QApplication.instance()
    if app is None:
        app = QtGui.QApplication(sys.argv)

    windowUI = GUI()

    if mode==0:
        windowUI.show()
    elif mode==1:
        pm.dockControl(aa="right", a="right", fl=0, con=windowUI.UI.objectName(), l="Miarmy GUI Collection")

    try:
        app.exec_()
    except:
        pass


#-----------------------------------------------------------------------------
if __name__ == '__main__':
    main(sys.argv[1:])


